@@ -5,7 +5,6 @@ from pygradus.config import settings as st
 
 HEADERS = {
     "accept": "application/json",
-    "Content-Type": "application/x-www-form-urlencoded",
 }
 
 API_MODE = {"post": requests.post, "get": requests.get}
@@ -14,12 +13,13 @@ API_MODE = {"post": requests.post, "get": requests.get}
 def send_request(
     mode: str,
     url: str,
-    data: dict = {},
-    json: dict = {},
+    data: dict = None,
+    json: dict = None,
     token: str = "",
 ):
 
     header = deepcopy(HEADERS)
+    header["Content-Type"] = st[mode]["content-type"]
     if token:
         header["Authorization"] = token
 
