@@ -1,14 +1,10 @@
-from api import send_request
-from config import settings as st
+from pygradus.api import send_request
+from pygradus.config import settings as st
 
 
 def check_solution(proposal, url=st.BASE_URL):
 
     r = send_request("attempt", url, json=proposal)
-    r = requests.post(
-        url + "/attempt/",
-        json=proposal,
-    )
     if r.status_code != 200:
         return r.text
     res = r.json()
